==> haskell-warp-tls-3.2.3-26-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.3
id: warp-tls-3.2.3-73uhDm8QKBLH5SewYSIyfW
key: warp-tls-3.2.3-73uhDm8QKBLH5SewYSIyfW
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: 218d2b36fe4976bef685d09655006fbc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/warp-tls-3.2.3
hs-libraries: HSwarp-tls-3.2.3-73uhDm8QKBLH5SewYSIyfW
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cryptonite-0.23-IZJ66Y8jjDgmndLH4VfVr
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    streaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
    tls-1.3.10-Blcr4Z6u3dE5lnvWI6RAH7
    wai-3.2.1.1-JO0pHQEhJIC6jTHZjPjdjR
    warp-3.2.12-zNSBMTWRcjDsaSWySiEbT
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.3-34-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.3
id: warp-tls-3.2.3-EyaHeWUUcV9GgxSeunrxNB
key: warp-tls-3.2.3-EyaHeWUUcV9GgxSeunrxNB
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: fbfecf1726176b9752d7352460def429
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/warp-tls-3.2.3
hs-libraries: HSwarp-tls-3.2.3-EyaHeWUUcV9GgxSeunrxNB
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cryptonite-0.23-3GIkE0SDPeuXan48X60bd
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    streaming-commons-0.1.18-LWHZCkHap5U1b7BVop9xwy
    tls-1.3.10-8VIusEGpzG86Cx9zRJiKeH wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    warp-3.2.12-6Y4kitQMsI8Cw3Gag1W6lt
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
